==> ompss-17.12.tar.gz: ompss-17.12/mcxx-2.1.0/tests/07_phases_ompss.dg/opencl/c/success_task_06.c <==
/*--------------------------------------------------------------------
  (C) Copyright 2006-2012 Barcelona Supercomputing Center
                          Centro Nacional de Supercomputacion
  
  This file is part of Mercurium C/C++ source-to-source compiler.
  
  See AUTHORS file in the top level directory for information
  regarding developers and contributors.
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 3 of the License, or (at your option) any later version.
  
  Mercurium C/C++ source-to-source compiler is distributed in the hope
  that it will be useful, but WITHOUT ANY WARRANTY; without even the
  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU Lesser General Public License for more
  details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with Mercurium C/C++ source-to-source compiler; if
  not, write to the Free Software Foundation, Inc., 675 Mass Ave,
  Cambridge, MA 02139, USA.
--------------------------------------------------------------------*/



/*
<testinfo>
test_generator=config/mercurium-opencl
compile_versions=ompss
</testinfo>
*/

#pragma omp target device(smp)
#pragma omp task
void f(int n_f_smp) {}

#pragma omp target device(opencl) ndrange(1,n_f_ocl,n_f_ocl) implements(f) file(t1.cl)
#pragma omp task
void f_ocl(int n_f_ocl);

int main()
{
    int n_main;
    f(n_main);
#pragma omp taskwait
}

==> ompss-19.06.tar.gz: ompss-19.06/mcxx-2.3.0/tests/07_phases_ompss.dg/opencl/c/success_task_06.c <==
/*--------------------------------------------------------------------
  (C) Copyright 2006-2012 Barcelona Supercomputing Center
                          Centro Nacional de Supercomputacion
  
  This file is part of Mercurium C/C++ source-to-source compiler.
  
  See AUTHORS file in the top level directory for information
  regarding developers and contributors.
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 3 of the License, or (at your option) any later version.
  
  Mercurium C/C++ source-to-source compiler is distributed in the hope
  that it will be useful, but WITHOUT ANY WARRANTY; without even the
  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU Lesser General Public License for more
  details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with Mercurium C/C++ source-to-source compiler; if
  not, write to the Free Software Foundation, Inc., 675 Mass Ave,
  Cambridge, MA 02139, USA.
--------------------------------------------------------------------*/



/*
<testinfo>
test_generator=config/mercurium-ompss-opencl
</testinfo>
*/

#pragma omp target device(smp)
#pragma omp task
void f(int n_f_smp) {}

#pragma omp target device(opencl) ndrange(1,n_f_ocl,n_f_ocl) implements(f) file(t1.cl)
#pragma omp task
void f_ocl(int n_f_ocl);

int main()
{
    int n_main;
    f(n_main);
#pragma omp taskwait
}
